@@ -1,6 +1,6 @@
 ;;; ebdb-ispell.el --- Add EBDB contact names to personal dictionaries  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2018  Free Software Foundation, Inc.
+;; Copyright (C) 2016-2020  Free Software Foundation, Inc.
 
 ;; Author: Eric Abrahamsen <eric@ericabrahamsen.net>
 
@@ -46,7 +46,7 @@
 	 (seq-mapcat
 	  (lambda (r)
 	    (ebdb-ispell-collect-words
-	     (cons (ebdb-record-name r)
+	     (cons (ebdb-record-name-string r)
 		   (ebdb-record-alt-names r))))
 	  (ebdb-records)))
 	(count 0))
@@ -85,8 +85,8 @@
 (defun ebdb-ispell-collect-words (strings)
   "Find all individual words in STRINGS and filter.
 Removes strings that are too short
-\(`ebdb-ispell-min-word-length'\) or explicitly ignored
-\(`ebdb-ispell-ignore-re'\)."
+\(`ebdb-ispell-min-word-length') or explicitly ignored
+\(`ebdb-ispell-ignore-re')."
   (seq-filter
    (lambda (word)
      (and (>= (length word) ebdb-ispell-min-word-length)
